==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QSplitter_shell.h <==
#ifndef QSPLITTER_SHELL_H
#define QSPLITTER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtwidgets-config.h>
#if QT_CONFIG(splitter)
#include <QtWidgets/qsplitter.h>
#endif //QT_CONFIG(splitter)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qtextstream.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qaction.h>
#include <QtWidgets/qframe.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(splitter)

class QSplitter_shell : public QSplitter, public QtJambiShellInterface
{
public:
    QSplitter_shell(QWidget* parent0 = nullptr);
    QSplitter_shell(Qt::Orientation arg__1, QWidget* parent1 = nullptr);
    ~QSplitter_shell() override;

    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* arg__1) override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* event0) override;
    QSplitterHandle* createHandle() override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void dropEvent(QDropEvent* event0) override;
    void enterEvent(QEvent* event0) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* arg__1) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void resizeEvent(QResizeEvent* arg__1) override;
    void setVisible(bool visible0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* event0) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSplitter_access : public QSplitter
{
    jint __qt_closestLegalPosition_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1, jint arg__2);
    void __qt_moveSplitter_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0, jint index1);
    void __qt_setRubberBand_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint position0);
    void __qt_changeEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_childEvent_QChildEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jobject __qt_createHandle(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jobject __qt_minimumSizeHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jobject __qt_sizeHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QT_CONFIG(splitter)
#endif // QSPLITTER_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QSplitter_shell.h <==
#ifndef QSPLITTER_SHELL_H
#define QSPLITTER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(splitter)
#include <QtWidgets/qsplitter.h>
#endif //QT_CONFIG(splitter)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qframe.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(splitter)

class QSplitter_shell : public QSplitter, public QtJambiShellInterface
{
public:
    QSplitter_shell(QWidget* parent0 = nullptr);
    QSplitter_shell(Qt::Orientation arg__1, QWidget* parent1 = nullptr);
    ~QSplitter_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QSplitter_mshell;
    friend class QSplitter_oshell;
};


class QSplitter_mshell : public QSplitter_shell
{
public:
    using QSplitter_shell::QSplitter_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QSplitter_oshell : public QSplitter_mshell
{
public:
    using QSplitter_mshell::QSplitter_mshell;
    ~QSplitter_oshell() override;
    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* arg__1) override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* event0) override;
    QSplitterHandle* createHandle() override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void dropEvent(QDropEvent* event0) override;
    void enterEvent(QEnterEvent* event0) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void initStyleOption(QStyleOptionFrame* option0) const override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* arg__1) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void resizeEvent(QResizeEvent* arg__1) override;
    void setVisible(bool visible0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* event0) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSplitter_access : public QSplitter
{
    jint __qt_closestLegalPosition_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1, jint arg__2);
    void __qt_moveSplitter_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0, jint index1);
    void __qt_setRubberBand_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint position0);
    void __qt_changeEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_childEvent_QChildEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jobject __qt_createHandle(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jobject __qt_minimumSizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jobject __qt_sizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QT_CONFIG(splitter)
#endif // QSPLITTER_SHELL_H
